.htaccess
COPYRIGHT.txt
LICENSE
admin
api.php
assets
composer.json
composer.lock
data
error.php
favicon.ico
includes
index.php
install
modules
robots.php
robots.txt
themes
uploads
vendor
web.config
config.php